@@ -10,6 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import typing as ty
 import uuid
 
 from openstack import resource
@@ -53,16 +54,21 @@ class Message(resource.Resource):
     #: in case keystone auth is not enabled in Zaqar service.
     project_id = resource.Header("X-PROJECT-ID")
 
+    # FIXME(stephenfin): This is actually a query arg but we need it for
+    # deletions and resource.delete doesn't respect these currently
+    claim_id: ty.Optional[str] = None
+
     def post(self, session, messages):
         request = self._prepare_request(requires_id=False, prepend_key=True)
         headers = {
             "Client-ID": self.client_id or str(uuid.uuid4()),
-            "X-PROJECT-ID": self.project_id or session.get_project_id()
+            "X-PROJECT-ID": self.project_id or session.get_project_id(),
         }
         request.headers.update(headers)
         request.body = {'messages': messages}
-        response = session.post(request.url,
-                                json=request.body, headers=request.headers)
+        response = session.post(
+            request.url, json=request.body, headers=request.headers
+        )
 
         return response.json()['resources']
 
@@ -82,14 +88,13 @@ class Message(resource.Resource):
         uri = base_path % params
         headers = {
             "Client-ID": params.get('client_id', None) or str(uuid.uuid4()),
-            "X-PROJECT-ID": params.get('project_id', None
-                                       ) or session.get_project_id()
+            "X-PROJECT-ID": params.get('project_id', None)
+            or session.get_project_id(),
         }
 
         query_params = cls._query_mapping._transpose(params, cls)
         while more_data:
-            resp = session.get(uri,
-                               headers=headers, params=query_params)
+            resp = session.get(uri, headers=headers, params=query_params)
             resp = resp.json()
             resp = resp[cls.resources_key]
 
@@ -111,19 +116,26 @@ class Message(resource.Resource):
             query_params["limit"] = yielded
             query_params["marker"] = new_marker
 
-    def fetch(self, session, requires_id=True,
-              base_path=None, error_message=None, skip_cache=False):
-        request = self._prepare_request(requires_id=requires_id,
-                                        base_path=base_path)
+    def fetch(
+        self,
+        session,
+        requires_id=True,
+        base_path=None,
+        error_message=None,
+        skip_cache=False,
+    ):
+        request = self._prepare_request(
+            requires_id=requires_id, base_path=base_path
+        )
         headers = {
             "Client-ID": self.client_id or str(uuid.uuid4()),
-            "X-PROJECT-ID": self.project_id or session.get_project_id()
+            "X-PROJECT-ID": self.project_id or session.get_project_id(),
         }
 
         request.headers.update(headers)
-        response = session.get(request.url,
-                               headers=headers,
-                               skip_cache=skip_cache)
+        response = session.get(
+            request.url, headers=headers, skip_cache=skip_cache
+        )
         self._translate_response(response)
 
         return self
@@ -132,7 +144,7 @@ class Message(resource.Resource):
         request = self._prepare_request()
         headers = {
             "Client-ID": self.client_id or str(uuid.uuid4()),
-            "X-PROJECT-ID": self.project_id or session.get_project_id()
+            "X-PROJECT-ID": self.project_id or session.get_project_id(),
         }
 
         request.headers.update(headers)
@@ -141,8 +153,7 @@ class Message(resource.Resource):
         # rebuild the request URI if claim_id is not None.
         if self.claim_id:
             request.url += '?claim_id=%s' % self.claim_id
-        response = session.delete(request.url,
-                                  headers=headers)
+        response = session.delete(request.url, headers=headers)
 
         self._translate_response(response, has_body=False)
         return self
