@@ -10,7 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import uuid
 
 from openstack.network.v2 import network
 from openstack.network.v2 import subnet
@@ -18,10 +17,6 @@ from openstack.tests.functional import base
 
 
 class TestSubnet(base.BaseFunctionalTest):
-
-    NET_NAME = uuid.uuid4().hex
-    SUB_NAME = uuid.uuid4().hex
-    UPDATE_NAME = uuid.uuid4().hex
     IPV4 = 4
     CIDR = "10.100.0.0/24"
     DNS_SERVERS = ["8.8.4.4", "8.8.8.8"]
@@ -30,37 +25,43 @@ class TestSubnet(base.BaseFunctionalTest):
     NET_ID = None
     SUB_ID = None
 
-    @classmethod
-    def setUpClass(cls):
-        super(TestSubnet, cls).setUpClass()
-        net = cls.conn.network.create_network(name=cls.NET_NAME)
+    def setUp(self):
+        super().setUp()
+        self.NET_NAME = self.getUniqueString()
+        self.SUB_NAME = self.getUniqueString()
+        self.UPDATE_NAME = self.getUniqueString()
+        net = self.user_cloud.network.create_network(name=self.NET_NAME)
         assert isinstance(net, network.Network)
-        cls.assertIs(cls.NET_NAME, net.name)
-        cls.NET_ID = net.id
-        sub = cls.conn.network.create_subnet(name=cls.SUB_NAME,
-                                             ip_version=cls.IPV4,
-                                             network_id=cls.NET_ID,
-                                             cidr=cls.CIDR,
-                                             dns_nameservers=cls.DNS_SERVERS,
-                                             allocation_pools=cls.POOL,
-                                             host_routes=cls.ROUTES)
+        self.assertEqual(self.NET_NAME, net.name)
+        self.NET_ID = net.id
+        sub = self.user_cloud.network.create_subnet(
+            name=self.SUB_NAME,
+            ip_version=self.IPV4,
+            network_id=self.NET_ID,
+            cidr=self.CIDR,
+            dns_nameservers=self.DNS_SERVERS,
+            allocation_pools=self.POOL,
+            host_routes=self.ROUTES,
+        )
         assert isinstance(sub, subnet.Subnet)
-        cls.assertIs(cls.SUB_NAME, sub.name)
-        cls.SUB_ID = sub.id
+        self.assertEqual(self.SUB_NAME, sub.name)
+        self.SUB_ID = sub.id
 
-    @classmethod
-    def tearDownClass(cls):
-        sot = cls.conn.network.delete_subnet(cls.SUB_ID)
-        cls.assertIs(None, sot)
-        sot = cls.conn.network.delete_network(cls.NET_ID, ignore_missing=False)
-        cls.assertIs(None, sot)
+    def tearDown(self):
+        sot = self.user_cloud.network.delete_subnet(self.SUB_ID)
+        self.assertIsNone(sot)
+        sot = self.user_cloud.network.delete_network(
+            self.NET_ID, ignore_missing=False
+        )
+        self.assertIsNone(sot)
+        super().tearDown()
 
     def test_find(self):
-        sot = self.conn.network.find_subnet(self.SUB_NAME)
+        sot = self.user_cloud.network.find_subnet(self.SUB_NAME)
         self.assertEqual(self.SUB_ID, sot.id)
 
     def test_get(self):
-        sot = self.conn.network.get_subnet(self.SUB_ID)
+        sot = self.user_cloud.network.get_subnet(self.SUB_ID)
         self.assertEqual(self.SUB_NAME, sot.name)
         self.assertEqual(self.SUB_ID, sot.id)
         self.assertEqual(self.DNS_SERVERS, sot.dns_nameservers)
@@ -72,10 +73,23 @@ class TestSubnet(base.BaseFunctionalTest):
         self.assertTrue(sot.is_dhcp_enabled)
 
     def test_list(self):
-        names = [o.name for o in self.conn.network.subnets()]
+        names = [o.name for o in self.user_cloud.network.subnets()]
         self.assertIn(self.SUB_NAME, names)
 
     def test_update(self):
-        sot = self.conn.network.update_subnet(self.SUB_ID,
-                                              name=self.UPDATE_NAME)
+        sot = self.user_cloud.network.update_subnet(
+            self.SUB_ID, name=self.UPDATE_NAME
+        )
         self.assertEqual(self.UPDATE_NAME, sot.name)
+
+    def test_set_tags(self):
+        sot = self.user_cloud.network.get_subnet(self.SUB_ID)
+        self.assertEqual([], sot.tags)
+
+        self.user_cloud.network.set_tags(sot, ["blue"])
+        sot = self.user_cloud.network.get_subnet(self.SUB_ID)
+        self.assertEqual(["blue"], sot.tags)
+
+        self.user_cloud.network.set_tags(sot, [])
+        sot = self.user_cloud.network.get_subnet(self.SUB_ID)
+        self.assertEqual([], sot.tags)
